pub struct AddFileRequest {
pub bucket_id: Uuid,
pub mount_path: String,
pub filename: String,
pub data: Vec<u8>,
}Expand description
Client-side request for adding a file via multipart upload. Wraps file data as a cursor for the ApiRequest trait.
Fields
bucket_id: Uuidmount_path: Stringfilename: Stringdata: Vec<u8>Trait Implementations
Sourceimpl ApiRequest for AddFileRequest
impl ApiRequest for AddFileRequest
type Response = AddResponse
fn build_request(self, base_url: &Url, client: &Client) -> RequestBuilder